summaryrefslogtreecommitdiffstats
path: root/src/configuredialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/configuredialog.cpp')
-rw-r--r--src/configuredialog.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/configuredialog.cpp b/src/configuredialog.cpp
index 93843ea..59f0fad 100644
--- a/src/configuredialog.cpp
+++ b/src/configuredialog.cpp
@@ -19,7 +19,7 @@
/*! \file configuredialog.cpp
* All here displayed file members of configureDialog.cpp are related to operations with the
* configure dialog for kpowersave
* \brief In this file can be found all configure dialog related code.
* \author Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
* \date 2005
@@ -226,7 +226,7 @@ void ConfigureDialog::setIcons(){
kdDebugFuncIn(trace);
/* set all Icons */
- this->setIcon(SmallIcon("kpowersave", TQIconSet::Automatic));
+ this->setIcon(SmallIcon("tdepowersave", TQIconSet::Automatic));
buttonApply->setIconSet(SmallIconSet("apply", TQIconSet::Automatic));
buttonCancel->setIconSet(SmallIconSet("cancel", TQIconSet::Automatic));
buttonOk->setIconSet(SmallIconSet("ok", TQIconSet::Automatic));
@@ -270,15 +270,15 @@ void ConfigureDialog::setTooltips(){
// TQToolTip::setWakeUpDelay ( 1000 );
TQToolTip::add(cB_specificSettings, i18n("This enables specific screen saver settings. \n"
"Note: If selected, the global screen saver settings are \n"
- "overwritten while kpowersave runs."));
+ "overwritten while tdepowersave runs."));
TQToolTip::add(cB_disable_Ss, i18n("This disables the screen saver. \n"
"Note: If selected, the global screen saver settings are \n"
- "overwritten while kpowersave runs."));
+ "overwritten while tdepowersave runs."));
TQToolTip::add(cB_blankScreen, i18n("This blanks the screen instead of using a specific screen saver. \n"
"Note: This may work only with KScreensaver."));
TQToolTip::add(cB_SpecificPM, i18n("This enables specific DPMS settings. \n"
"Note: If selected, the global DPMS settings are \n"
- "overwritten while kpowersave runs."));
+ "overwritten while tdepowersave runs."));
TQToolTip::add(cB_disablePM, i18n("This disables DPMS support."));
TQToolTip::add(cB_lockSuspend, i18n("If selected, the screen is locked on suspend or standby."));
TQToolTip::add(cB_lockLid, i18n("If selected, the screen is locked if the lid close event is triggered."));
@@ -1035,7 +1035,7 @@ void ConfigureDialog::pB_newScheme_clicked(){
getSchemeList();
while (!_end) {
- _new = KInputDialog::getText( i18n("KPowersave Configuration"),
+ _new = KInputDialog::getText( i18n("TDEPowersave Configuration"),
_error + _text, TQString(), &_ok, this);
if (!_ok ) {
_end = true;
@@ -19,7 +19,7 @@
/*! \file configuredialog.cpp
* All here displayed file members of configureDialog.cpp are related to operations with the
- * configure dialog for kpowersave
+ * configure dialog for tdepowersave
* \brief In this file can be found all configure dialog related code.
* \author Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>